Page 89 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 89

Home

    century.
    Another method of accumulating great wealth is

    through lending the government money created out of
    nothing more than a bookkeeping entry, and then earning
    interest on this money. A feature of this system is that the
    introduction of unbacked money actually serves as a
    hidden tax by decreasing the buying power of all the
    money in circulation.

    This method (inflation of the money supply) has been
    used to the extent that $10,000 in 1940 now has the
    buying power of only $500. By 1971 all ties of gold or
    silver to our paper currency had been eliminated, making
    it possible to inflate it to worthlessness, as was done in
    Germany prior to the rise of Hitler.

    Once the Federal Reserve had the power to lend vast

    amounts of money to the government, and the income tax
    had been established as a way to collect the money to
    pay the interest on the loans, the United States was on its
    way to becoming one of the worlds largest debtor
    nations.

    This debt is increasing at the rate of a billion dollars
    a day. As a result a gigantic crisis is being created to lead
    us into a one world monetary system under the control of
    the same people who created the problem.

    The president of American Media, G. Edward Griffin,
    gave this possible scenario regarding inflation:

    84

    The Secret Side of History

    before. In other words, The Federal Reserve has been

    manipulating the American economy for nearly a